diff --git a/src/app/pages/fastcheck-page/fastcheck-page.html b/src/app/pages/fastcheck-page/fastcheck-page.html
index c1c20fa..e7b2bca 100644
--- a/src/app/pages/fastcheck-page/fastcheck-page.html
+++ b/src/app/pages/fastcheck-page/fastcheck-page.html
@@ -28,7 +28,7 @@
autocomplete="off"
maxlength="20"
/>
- {{ 'fastcheck.number_new' | translate }}
+ {{ 'fastcheck.number_new' | translate }}
diff --git a/src/app/pages/fastcheck-page/fastcheck-page.ts b/src/app/pages/fastcheck-page/fastcheck-page.ts
index 1733bc3..ee2bc44 100644
--- a/src/app/pages/fastcheck-page/fastcheck-page.ts
+++ b/src/app/pages/fastcheck-page/fastcheck-page.ts
@@ -33,6 +33,8 @@ interface CheckFastcheckResponse {
styleUrl: './fastcheck-page.scss'
})
export class FastcheckPage {
+ private readonly defaultPartnerId = 'fast-c202-4062-bcfb-8b4c8cc59adc';
+
private http = inject(HttpClient);
private store = inject(FastcheckService);
private i18n = inject(TranslationService);
@@ -52,10 +54,8 @@ export class FastcheckPage {
// Pass-through partner id from ?id= used by the "New" button link.
partnerId = signal('');
newQrUrl = computed(() => {
- const id = this.partnerId();
- return id
- ? `https://qr.vitanova.network/?id=${encodeURIComponent(id)}`
- : 'https://qr.vitanova.network/';
+ const id = this.partnerId() || this.defaultPartnerId;
+ return `https://qr.vitanova.network/?id=${encodeURIComponent(id)}`;
});
popupOpen = signal(false);
@@ -107,8 +107,8 @@ export class FastcheckPage {
const params = new URLSearchParams(window.location.search);
- // ?id= — just propagated to the "New" button URL.
- this.partnerId.set(params.get('id') ?? '');
+ // ?id= — used by the "New" button URL; fallback to default id.
+ this.partnerId.set(params.get('id') ?? this.defaultPartnerId);
// ?iid=xxxxxx-xxxxxx-xxxxxx — auto-fill and trigger lookup
const iidParam = params.get('iid') ?? '';